#
# spec file for package apache2-mod_auth_token
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mod_name mod_auth_token
#
Name:           apache2-mod_auth_token
Version:        1.0.5
Release:        lp150.10.8
Summary:        Token-based authentication similar to mod_secdownload in LIGHTTPD
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            http://www.synd.info/downloads/releases/
Source:         http://www.synd.info/downloads/releases/%{mod_name}-%{version}.tar.gz
Patch0:         mod_auth_token-1.0.5-terminating_NULL.diff
Patch1:         auth_token_ap24.patch
BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
BuildRequires:  curl
BuildRequires:  libtool
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This module uses token based authentication to secure downloads and prevent
deep-linking.

Have your PHP script or servlet generate the to authenticate the
download. Apache can then treat the download request like a normal file
transfer without having to pipe the file through a script in order to
add authentication.

%prep
%setup -q -n %{mod_name}-%{version}
%patch0 -p1
%patch1

%build
./buildconf
%configure --with-apxs="%{apache_apxs}"
make %{?_smp_mflags}

%install
install -Dd -m 0755 %{buildroot}%{apache_libexecdir}
%{apache_apxs} -S LIBEXECDIR="%{buildroot}%{apache_libexecdir}" -i %{mod_name}.la

%check
set +x
# see http://search.cpan.org/~agordon/Authen-ModAuthToken-0.03/lib/Authen/ModAuthToken.pm
#     https://code.google.com/p/mod-auth-token/
# for details
#
# create area protected by token mechanism
mkdir -p %{apache_test_module_dir}/htdocs/protected
# and a file in it
cat << EOF > %{apache_test_module_dir}/htdocs/protected/file.txt
HOLA
EOF
# configure mod_auth_token
cat << EOF > %{apache_test_module_dir}/mod_auth_token-test.conf
<Location /protected/>
  AuthTokenSecret   "secret"
  AuthTokenPrefix   /protected/
  AuthTokenTimeout  60
</Location>
EOF
exit_code=0
# start apache test instance
%apache_test_module_start_apache -m auth_token -i mod_auth_token-test.conf
# create token depending on secret string, file name and time
now_hex=$(printf "%x" $(date +%s));
token=$(echo -n "secret/file.txt$now_hex" | md5sum | cut -c -32)
echo
# direct acces to file.txt must not work
echo 'Testing direct access to /protected/file.txt output'
%apache_test_module_curl -d /protected/file.txt -o error.txt
grep '<title>.*401.*</title>' error.txt || exit_code=1
# acces to file.txt via token must work
echo "Testing acces to /protected/$token/$now_hex/file.txt"
%apache_test_module_curl -d /protected/$token/$now_hex/file.txt -o downloaded-file.txt
grep 'HOLA' downloaded-file.txt || exit_code=1
if [ $exit_code -eq 0 ]; then
  echo 'SUCCESS'
else
  echo 'FAILED, error_log:'
  cat %{apache_test_module_dir}/error_log
fi
echo
# stop apache test instance
%apache_test_module_stop_apache
set -x
exit $exit_code

%files
%defattr(-,root,root,-)
%{apache_libexecdir}/%{mod_name}.so
%doc AUTHORS README ChangeLog LICENSE

%changelog
* Fri Oct  2 2015 pgajdos@suse.com
- do %%check for Apache 2.2 again
* Thu Oct  1 2015 pgajdos@suse.com
- do not %%check for Apache 2.2
* Wed Sep 23 2015 pgajdos@suse.com
- test with %%apache_test_module_curl
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Oct 31 2014 pgajdos@suse.com
- call spec cleaner
- use apache rpm macros
* Tue Aug  7 2012 crrodriguez@opensuse.org
- Fix per-module logging in apache 2.4
* Wed Aug  1 2012 crrodriguez@opensuse.org
- Fix build, missing BUildRequires.
* Fri Mar  4 2011 draht@suse.de
- fix brokenness with _service file that didn't work
* Thu Mar  3 2011 crrodriguez@opensuse.org
- Update to version 1.0.5
* Thu Mar  3 2011 draht@suse.de
- mod_auth_token-1.0.2-terminating_NULL.diff adds required
  terminating NULL to apr_pstrcat()
